autowisp.database.data_model.provenance.camera_type module — AutoWISP documentation

# autowisp.database.data_model.provenance.camera_type module

## Class Inheritance Diagram

Define the camera type dataset table for the pipeline

class autowisp.database.data_model.provenance.camera_type.CameraType(**kwargs)

  Bases: `DataModelBase`

  The table describing the different camera types

  cameras
  channels
  id

    A unique identifier for each row.

  make

    The make of the camera

  model

    The model of the camera

  notes

    The notes provided for the camera type

  pixel_size

    The pixel size of the camera in microns

  sensor_type

    The sensor type of the camera

  timestamp

    When record was last changed

  version

    The version of the camera

  x_resolution

    The x_resolution of the camera

  y_resolution

    The y_resolution of the camera